# FreeAlchemist

FreeAlchemist is a figure block game written in Python where you have to connect blocks.
The three or more blocks connected with the same shape will be replaced by a block with a different shape. 


## Setup

```bash
sudo python3 setup.py install
```

## Run

```bash
freealchemist
```

## License

See LICENSE file